/**
 * EWOD Pad Analyzer. 
 * 
 * The simulations below show the overlap function of two adjacent pats. 
 * The graph represents the total vertical area of the pad in y direction as function of the x direction. 
 * 2016, Urs Gaudenz, GaudiLabs

 * Note that this sketch will behave differently on Android, 
 * since most images will no longer be full 24-bit color.
 */

// The next line is needed if running in JavaScript Mode with Processing.js
/* @pjs preload="frontier.jpg"; */ 
String filename="FinalPad_1_halfe.png";
PImage img = loadImage(filename);
size(img.width, img.height+200);

// Load an image from the data directory
// Load a different image by modifying the comments

image(img, 0, 0);
int[] red_f = new int[img.width];
int[] green_f = new int[img.width];

int red_sum=0, green_sum=0;

// Calculate the overlap
for (int x = 0; x < img.width; x++) {
  for (int y = 0; y < img.height; y++) {
    int red = int(red(get(x, y)));
    int green = int(green(get(x, y)));
 if (red>100) red_f[x]++;
 if (green>100) green_f[x]++;
  }
  red_sum+=red_f[x];
  green_sum+=green_f[x];
}


// Draw half of the graph 

int red_Max = max(red_f);
int green_Max = max(green_f);
int c_max=max(red_Max,green_Max);

stroke(20);
fill(20);
rect(0,img.height+1, img.width, img.height+180);

stroke(50);

for (int y = 0; y <= 10; y++)
  line(0, img.height+180-y*16, img.width, img.height+180-y*16);



for (int x = 1; x < img.width; x += 1) {

stroke(255,0,0);
  line(x, img.height+180-(red_f[x-1]*160/c_max), x, img.height+180-(red_f[x]*160/c_max));
stroke(0,255,0);
  line(x, img.height+180-(green_f[x-1]*160/c_max), x, img.height+180-(green_f[x]*160/c_max));



}

fill(255,0,0);
textSize(14);
text(red_sum/img.height, 10, img.height+50);

fill(0,255,0);
textSize(14);
text(green_sum/img.height, 10, img.height+66);

fill(255,255,0);
textSize(14);
text((red_sum+green_sum)/img.height, 10, img.height+82);

String Filename2 = "data/output_"+filename;

save(Filename2);
